<?php
/***************************************************************************
 *						Theme Modules
 * 	----------------------------------------------------------------------
 * 						DO NOT EDIT THIS FILE
 *	----------------------------------------------------------------------
 *
 *  					Copyright (C) Themify
 * 						http://themify.me
 *
 *  To add custom modules to the theme, create a new 'custom-modules.php' file in the theme folder.
 *  They will be added to the theme automatically.
 *
 ***************************************************************************/

/**
 * Default Index Layout Module
 * @param array $data Theme settings data
 * @return string Markup for module.
 * @since 1.0.0
 */
function themify_default_layout( $data = array() ) {
	$data = themify_get_data();
	/**
	 * Theme Settings Option Key Prefix
	 * @var string
	 */
	$prefix = 'setting-default_';

	if ( ! isset( $data[$prefix.'more_text'] ) || '' == $data[$prefix.'more_text'] ) {
		$more_text = __('More', 'themify');
	} else {
		$more_text = $data[$prefix.'more_text'];
	}
	/**
	 * Tertiary options <blank>|yes|no
	 * @var array
	 */
	$default_options = array(
		array('name' => '', 'value' => ''),
		array('name' => __('Yes', 'themify'), 'value' => 'yes'),
		array('name' => __('No', 'themify'), 'value' => 'no')
	);
	/**
	 * Post content display options
	 * @var array
	 */
	$default_display_options = array(
		array('name' => __('Full Content', 'themify'),'value' => 'content'),
		array('name' => __('Excerpt', 'themify'),'value' => 'excerpt'),
		array('name' => __('None', 'themify'),'value' => 'none')
	);
	/**
	 * Post layout options
	 * @var array
	 */
	$default_post_layout_options = array(
		array('value' => 'list-post', 'img' => 'images/layout-icons/list-post.png', 'title' => __('List Post', 'themify')),
		array('value' => 'grid4', 'img' => 'images/layout-icons/grid4.png', 'title' => __('Grid 4', 'themify')),
		array('value' => 'grid3', 'img' => 'images/layout-icons/grid3.png', 'title' => __('Grid 3', 'themify')),
		array('value' => 'grid2', 'img' => 'images/layout-icons/grid2.png', 'title' => __('Grid 2', 'themify'), 'selected' => true),
		array('value' => 'list-large-image', 'img' => 'images/layout-icons/list-large-image.png', 'title' => __('List Large Image', 'themify')),
		array('value' => 'list-thumb-image', 'img' => 'images/layout-icons/list-thumb-image.png', 'title' => __('List Thumb Image', 'themify')),
		array('value' => 'grid2-thumb', 'img' => 'images/layout-icons/grid2-thumb.png', 'title' => __('Grid 2 Thumb', 'themify')),
	);
	/**
	 * Sidebar placement options
	 * @var array
	 */
	$sidebar_location_options = array(
		array('value' => 'sidebar2', 'img' => 'images/layout-icons/sidebar2.png', 'title' => __('Left and Right', 'themify'), 'selected' => true),
		array('value' => 'sidebar2 content-left', 'img' => 'images/layout-icons/sidebar2-content-left.png', 'title' => __('2 Right Sidebars', 'themify')),
		array('value' => 'sidebar2 content-right', 'img' => 'images/layout-icons/sidebar2-content-right.png', 'title' => __('2 Left Sidebars', 'themify')),
		array('value' => 'sidebar1', 'img' => 'images/layout-icons/sidebar1.png', 'title' => __('Sidebar Right', 'themify')),
		array('value' => 'sidebar1 sidebar-left', 'img' => 'images/layout-icons/sidebar1-left.png', 'title' => __('Sidebar Left', 'themify')),
		array('value' => 'sidebar-none', 'img' => 'images/layout-icons/sidebar-none.png', 'title' => __('No Sidebar', 'themify'))
	);
	/**
	 * Image alignment options
	 * @var array
	 */
	$alignment_options = array(
		array('name' => '', 'value' => ''),
		array('name' => __('Left', 'themify'), 'value' => 'left'),
		array('name' => __('Right', 'themify'), 'value' => 'right')
	);

	/**
	 * HTML for settings panel
	 * @var string
	 */
	$output = '<div class="themify-info-link">' . __( 'Here you can set the <a href="https://themify.me/docs/default-layouts">Default Layouts</a> for WordPress archive post layout (category, search, archive, tag pages, etc.), single post layout (single post page), and the static Page layout. The default single post and page layout can be override individually on the post/page > edit > Themify Custom Panel.', 'themify' ) . '</div>';

	/**
	 * Index Sidebar Option
	 */
	$output .= '<p>
					<span class="label">' . __('Archive Sidebar Option', 'themify') . '</span>';
	$val = isset( $data[$prefix.'layout'] ) ? $data[$prefix.'layout'] : '';
	foreach ( $sidebar_location_options as $option ) {
		if ( ( '' == $val || ! $val || ! isset( $val ) ) && ( isset( $option['selected'] ) && $option['selected'] ) ) {
			$val = $option['value'];
		}
		if ( $val == $option['value'] ) {
			$class = 'selected';
		} else {
			$class = '';
		}
		$output .= '<a href="#" class="preview-icon '.$class.'" title="'.$option['title'].'"><img src="'.THEME_URI.'/'.$option['img'].'" alt="'.$option['value'].'"  /></a>';
	}

	$output .= '	<input type="hidden" name="'.$prefix.'layout" class="val" value="'.$val.'" />
				</p>';
	/**
	 * Post Layout
	 */
	$output .= '<p>
					<span class="label">' . __('Post Layout', 'themify') . '</span>';
	$val = isset( $data[$prefix.'post_layout'] ) ? $data[$prefix.'post_layout'] : '';
	foreach ( $default_post_layout_options as $option ) {
		if ( ( '' == $val || ! $val || ! isset( $val ) ) && ( isset( $option['selected'] ) && $option['selected'] ) ) {
			$val = $option['value'];
		}
		if ( $val == $option['value'] ) {
			$class = 'selected';
		} else {
			$class = '';
		}
		$output .= '<a href="#" class="preview-icon '.$class.'" title="'.$option['title'].'"><img src="'.THEME_URI.'/'.$option['img'].'" alt="'.$option['value'].'"  /></a>';
	}

	$output .= '	<input type="hidden" name="'.$prefix.'post_layout" class="val" value="'.$val.'" />
				</p>';
	/**
	 * Display Content
	 */
	$output .= '<p>
					<span class="label">' . __('Display Content', 'themify') . '</span>
					<select name="'.$prefix.'layout_display">'.
						themify_options_module($default_display_options, $prefix.'layout_display').'
					</select>
				</p>';

	/**
	 * More Text
	 */
	$output .= '<p>
					<span class="label">' . __('More Text', 'themify') . '</span>
					<input type="text" name="'.$prefix.'more_text" value="'.$more_text.'">
				</p>';
				
	/**
	 * Display more link in excerpt mode
	 */
	$output .= '<span class="pushlabel vertical-grouped"><label for="setting-excerpt_more"><input type="checkbox" value="1" id="setting-excerpt_more" name="setting-excerpt_more" '.checked( themify_get( 'setting-excerpt_more' ), 1, false ).'/> ' . __('Display more link button in excerpt mode as well.', 'themify') . '</label></span>';

	/**
	 * Order & OrderBy Options
	 */
	$output .= themify_post_sorting_options('setting-index_order', $data);

	/**
	 * Hide Post Title
	 */
	$output .= '<p>
					<span class="label">' . __('Hide Post Title', 'themify') . '</span>
					<select name="'.$prefix.'post_title">' .
						themify_options_module($default_options, $prefix.'post_title') . '
					</select>
				</p>';

	/**
	 * Unlink Post Title
	 */
	$output .= '<p>
					<span class="label">' . __('Unlink Post Title', 'themify') . '</span>
					<select name="'.$prefix.'unlink_post_title">' .
						themify_options_module($default_options, $prefix.'unlink_post_title') . '
					</select>
				</p>';

	/**
	 * Hide Post Meta
	 */
	$output .= themify_post_meta_options($prefix.'post_meta', $data);

	/**
	 * Hide Post Date
	 */
	$output .= '<p>
					<span class="label">' . __('Hide Post Date', 'themify') . '</span>
					<select name="'.$prefix.'post_date">' .
						themify_options_module($default_options, $prefix.'post_date') . '
					</select>
				</p>';

	/**
	 * Auto Featured Image
	 */
	$output .= '<p>
					<span class="label">' . __('Auto Featured Image', 'themify') . '</span>
					<label for="setting-auto_featured_image"><input type="checkbox" value="1" id="setting-auto_featured_image" name="setting-auto_featured_image" '.checked( themify_get( 'setting-auto_featured_image' ), 1, false ).'/> ' . __('If no featured image is specified, display first image in content.', 'themify') . '</label>
				</p>';

	/**
	 * Hide Featured Image
	 */
	$output .= '<p>
					<span class="label">' . __('Hide Featured Image', 'themify') . '</span>
					<select name="'.$prefix.'post_image">' .
						themify_options_module($default_options, $prefix.'post_image') . '
					</select>
				</p>';

	/**
	 * Unlink Featured Image
	 */
	$output .= '<p>
					<span class="label">' . __('Unlink Featured Image', 'themify') . '</span>
					<select name="'.$prefix.'unlink_post_image">' .
						themify_options_module($default_options, $prefix.'unlink_post_image') . '
					</select>
				</p>';

	/**
	 * Featured Image Sizes
	 */
	$output .= themify_feature_image_sizes_select('image_post_feature_size');

	/**
	 * Image Dimensions
	 */
	$output .= '<p>
					<span class="label">' . __('Image Size', 'themify') . '</span>
					<input type="text" class="width2" name="setting-image_post_width" value="' . themify_get( 'setting-image_post_width' ) . '" /> ' . __('width', 'themify') . ' <small>(px)</small>
					<input type="text" class="width2 show_if_enabled_img_php" name="setting-image_post_height" value="' . themify_get( 'setting-image_post_height' ) . '" /> <span class="show_if_enabled_img_php">' . __('height', 'themify') . ' <small>(px)</small></span>
					<br /><span class="pushlabel show_if_enabled_img_php"><small>' . __('Enter height = 0 to disable vertical cropping with img.php enabled', 'themify') . '</small></span>
				</p>';

	return $output;
}

/**
 * Markup for fixed header selection module
 * @param array $data
 * @return string
 */
function themify_fixed_header_module( $data = array() ) {
	$data = themify_get_data();
	/**
	 * Variable key in theme settings
	 * @var string
	 */
	$key = 'setting-fixed_header_disabled';

	/**
	 * Module markup
	 * @var string
	 */
	$html = sprintf('<p><label for="%1$s"><input type="checkbox" id="%1$s" name="%1$s" %2$s /> %3$s</label></p>',
		$key,
		checked( themify_get( $key ), 'on', false ),
		__('Check to disable Fixed Header.', 'themify')
	);

	return $html;
}

/**
 * Markup for breaking news module
 * @param array $data
 * @return string
 */
function themify_breaking_news_module( $data = array() ) {
	$data = themify_get_data();
	/**
	 * Variable key in theme settings
	 * @var string
	 */
	$key = 'setting-breaking_news';

	/**
	 * Category list
	 * @var array
	 */
	$categories = array_merge( array(
		'off' => array(
			'name' => __('Disable Breaking News Module', 'themify'),
			'value'	=> ''
		),
		'all' => array(
			'name' => __('All Categories', 'themify'),
			'value' => 'all-categories'
		)
	), themify_theme_get_terms() );

	/**
	 * Tag list
	 * @var array
	 */
	$tags = array_merge( array(
		'off' => array(
			'name' => __('Disable Breaking News Module', 'themify'),
			'value'	=> ''
		)
	), themify_theme_get_terms('post_tag') );
	/**
	 * Auto timeout options
	 * @var array
	 */
	$auto_options = array(
		array('name' => __('Off', 'themify'),	'value' => 'off'),
		array('name' => __('1 Sec', 'themify'), 'value' => '1000'),
		array('name' => __('2 Secs', 'themify'), 'value' => '2000'),
		array('name' => __('3 Secs', 'themify'), 'value' => '3000'),
		array('name' => __('4 Sec', 'themify'), 'value' => '4000'),
		array('name' => __('5 Secs', 'themify'), 'value' => '5000'),
		array('name' => __('6 Secs', 'themify'), 'value' => '6000'),
		array('name' => __('7 Sec', 'themify'), 'value' => '7000'),
		array('name' => __('8 Secs', 'themify'), 'value' => '8000'),
		array('name' => __('9 Secs', 'themify'), 'value' => '9000'),
		array('name' => __('10 Secs', 'themify'), 'value' => '10000')
	);
	/**
	 * Effect options
	 * @var array
	 */
	$effect_options = array(
		array('name' => __('Slide', 'themify'), 'value' => 'slide'),
		array('name' => __('Fade', 'themify'), 'value' =>'fade')
	);
	/**
	 * Transition speed options
	 * @var array
	 */
	$speed_options = array(
		array('name' => __('Fast', 'themify'), 'value' => '500'),
		array('name' => __('Normal', 'themify'), 'value' => '1000'),
		array('name' => __('Slow', 'themify'), 'value' => '1500')
	);

	/**
	 * Set taxonomy, category or post_tag to be shown in breaking news
	 */
	$display_category = '';
	$display_category_display = '';
	$display_post_tag = '';
	$display_post_tag_display = '';
	if ( 'post_tag' == themify_get( $key.'_tax' ) ) {
		$display_post_tag = 'checked="checked"';
		$display_category_display = 'style="display:none;"';
	} else {
		$display_category = 'checked="checked"';
		$display_post_tag_display = 'style="display:none;"';
	}

	/**
	 * Module markup
	 * @var string
	 */
	$html = '';

	$html .= '<p>
				<span class="label">' . __('Breaking News Display', 'themify') . '</span>
				<input type="radio" class="block-toggle" name="'.$key.'_tax" value="category" data-hide="post_tag" '.$display_category.' /> ' . __('Categories', 'themify') . '

				<input type="radio" class="block-toggle" name="'.$key.'_tax" value="post_tag" data-hide="category" '.$display_post_tag.' /> ' . __('Tags', 'themify') .
			'</p>';

	$html .= sprintf('
		<p class="feature_box_category" %s>
			<span class="pushlabel"><select name="%s">%s</select></span>
			<span class="pushlabel"><small>%s</small></span>
		</p>',
		$display_category_display,
		$key,
		themify_options_module($categories, $key),
		__('Select a Category to display or disable it completely.', 'themify')
	);

	$html .= sprintf('
		<p class="feature_box_post_tag" %s>
			<span class="pushlabel"><select name="%s">%s</select></span>
			<span class="pushlabel"><small>%s</small></span>
		</p>',
		$display_post_tag_display,
		$key . '_tag',
		themify_options_module($tags, $key . '_tag'),
		__('Select a Tag to display or disable it completely.', 'themify')
	);

	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<input size="2" type="text" name="%s" value="%s" />
		</p>',
		__('Limit', 'themify'),
		$key.'_limit',
		esc_attr( themify_get( $key.'_limit' ) )
	);

	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<select name="%s">%s</select>
		</p>',
		__('Auto Play', 'themify'),
		$key.'_slider_autoplay',
		themify_options_module($auto_options, $key.'_slider_autoplay', true, 4000)
	);

	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<select name="%s">%s</select>
		</p>',
		__('Effect', 'themify'),
		$key.'_slider_effect',
		themify_options_module($effect_options, $key.'_slider_effect')
	);

	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<select name="%s">%s</select>
		</p>',
		__('Transition Speed', 'themify'),
		$key.'_slider_speed',
		themify_options_module($speed_options, $key.'_slider_speed')
	);

	return $html;
}

/**
 * Markup for related posts module
 * @param array $data
 * @return string
 */
function themify_related_posts_module( $data = array() ) {
	$data = themify_get_data();
	/**
	 * Variable key in theme settings
	 * @var string
	 */
	$key = 'setting-related_posts';

	/**
	 * Binary options yes|no
	 * @var array
	 */
	$binary = array(
		array('name' => __('Yes', 'themify'), 'value' => 'yes'),
		array('name' => __('No', 'themify'), 'value' => 'no')
	);

	/**
	 * Module markup
	 * @var string
	 */
	$html = '';

	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<select name="%s">%s</select>
			<span class="pushlabel"><small>%s</small></span>
		</p>',
		__('Show Related Posts', 'themify'),
		$key,
		themify_options_module($binary, $key),
		__('Related posts are only visible in single post view.', 'themify')
	);

	/**
	 * Number of posts
	 */
	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<input type="text" class="width2" name="%s" value="%s" />
			<br /><span class="pushlabel"><small>%s</small></span>
		</p>',
		__('Number of Entries', 'themify'),
		$key.'_limit',
		themify_get( $key.'_limit' ),
		__('Enter the number of posts to show.', 'themify')
	);

	/**
	 * Image Dimensions
	 */
	$html .= sprintf('
		<p>
			<span class="label">%s</span>
			<input type="text" class="width2" name="%s" value="%s" /> %s <small>(px)</small>
			<input type="text" class="width2" name="%s" value="%s" /> %s <small>(px)</small>
			<br /><span class="pushlabel"><small>%s</small></span>
		</p>',
		__('Image Size', 'themify'),
		$key.'_width',
		themify_get( $key.'_width' ),
		__('width', 'themify'),
		$key.'_height',
		themify_get( $key.'_height' ),
		__('height', 'themify'),
		__('Enter height = 0 to disable vertical cropping with img.php enabled', 'themify')
	);

	return $html;
}

/**
 * Markup for social share module
 * @param array $data
 * @return string
 */
function themify_social_share_module( $data = array() ) {
	$data = themify_get_data();

	$metas = array (
		'facebook' 	  => __('Facebook', 'themify'),
		'twitter' 	  => __('Twitter', 'themify'),
		'googleplus'  => __('Google+', 'themify'),
		'pinterest'   => __('Pinterest', 'themify'),
		'stumbleupon' => __('StumbleUpon', 'themify'),
		'linkedin'    => __('LinkedIn', 'themify'),
	);

	$states = array(
		array(
			'name' => __('Enable', 'themify'),
			'value' => 'yes',
			'icon' => THEMIFY_URI . '/img/ddbtn-check.png',
			'title' => __('Enable', 'themify')
		),
		array(
			'name' => __('Disable', 'themify'),
			'value' => 'no',
			'icon' => THEMIFY_URI . '/img/ddbtn-cross.png',
			'title' => __('Disable', 'themify')
		)
	);

	$default = array(
		'name' => __('Theme', 'themify'),
		'value' => '',
		'icon' => THEMIFY_URI . '/img/ddbtn-blank.png',
		'title' => __('Use theme settings', 'themify')
	);

	/**
	 * Module markup
	 * @var string
	 */
	$out = '<span class="label">' . __( 'Post Share', 'themify' ) . '</span><div class="themify_field_row dropdownbutton-group pushlabel">';

	foreach($metas as $meta => $name) {
		$metakey = 'setting-' . $meta;
		$meta_class = 'ddbtn-sub ddbtn-'.$meta;
		$first = '';
		$others = '';
		$out .=	'
		<div id="'.$metakey.'" class="dropdownbutton-list" data-name="'.$name.'" data-def-icon="'.$default['icon'].'">';
		
		// default state
		$first = '
			<div class="first-ddbtn">
				<a href="#" data-val="'.$default['value'].'" data-name="'.$default['name'].'" title="'.$default['title'].'">
					<img src="'.$default['icon'].'" title="'.$default['title'].'" />
					<span class="ddbtn-name">'.$name.'</span>
				</a>
			</div>';

		foreach( $states as $state ) {
			if( isset( $state['value'] ) && isset( $data[$metakey] ) && $state['value'] == $data[$metakey] ) {
				$first = '
				<div class="first-ddbtn">
					<a href="#" data-val="'.$state['value'].'" data-name="'.$state['name'].'" title="'.$state['title'].'">
						<img src="'.$state['icon'].'" title="'.$state['title'].'" />
						<span class="ddbtn-name">'.$name.'</span>
					</a>
				</div>';
				$selected = 'selected';
				//$hide = 'ddbtn-hide';
				$hide = '';
			} else {
				$selected = '';
				$hide = '';
			}
			
			$others .= '
				<div class="ddbtn '.$hide.'">
					<a href="#" data-sel="'.$selected.'" data-val="'.$state['value'].'" data-name="'.$state['name'].'" title="'.$state['title'].'">
						<img src="'.$state['icon'].'" title="'.$state['title'].'" />
						<span class="ddbtn-label">'.$state['name'].'</span>
					</a>
				</div>';
		}
		$out .= $first . '<div class="dropdownbutton">' . $others . '</div>';
		$out .= '
		</div>';
		$meta_key_data = themify_get( $metakey );
		$out .= '<input type="hidden" value="'.$meta_key_data.'" class="'.$meta_class.'" id="'.$metakey.'" name="'.$metakey.'" />';
	}

	$out .= '</div>';
	$out .= '<div class="clear"></div>';
	$out .= '<div class="pushlabel"><small>' . __( 'Only visible in single post view.', 'themify' ) . '</small></div>';

	return $out;
}

if( ! function_exists( 'themify_theme_get_terms' ) ) {
	/**
	 * Return terms from specified taxonomy
	 * @param string $terms_tax
	 * @return mixed|void
	 */
	function themify_theme_get_terms( $terms_tax = 'category' ) {
		$terms_by_tax = get_terms($terms_tax);
		$terms_list = array();
		foreach ($terms_by_tax as $term) {
			$terms_list[$term->term_id] = array(
				'name' => $term->name,
				'value'	=> $term->slug
			);
		}
		return apply_filters("themify_theme_get_{$terms_tax}_terms", $terms_list);
	}
}